#!/usr/bin/env python3
# encoding: utf-8
#
# Copyright (C) 2020 Timm Fitschen <t.fitschen@indiscale.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
#
"""
Accept a loan request.
"""
from __future__ import absolute_import

import caosdb as db
from caosadvancedtools.serverside.helper import get_timestamp, print_success

from .box_loan import (F_LOAN, LOAN_ACCEPTED, S_LOAN_ACCEPTED, S_LOAN_REQUESTED, get_borrower_names,
                       get_loan, main, set_property, update_loan_state)


def _accept_loan_request(loan):
    """Update a loan Record: add the `accepted` Property."""
    # This changes the state from "loan_requested" to "loan_accepted".
    update_loan_state(loan, S_LOAN_ACCEPTED)

    db.Container().extend([loan]).update()


def accept_loan_request(data):
    """Accept a loan request.

    I.e. add the `accepted` Property to the `Loan` Record.
    """
    loan = get_loan(data[F_LOAN])
    _accept_loan_request(loan)
    fn, ln = get_borrower_names(loan)

    print_success('Thank you for accepting the loan request by {fn} {ln}. See '
                  '<a href="{loan}" title="Go to the accepted loan '
                  'request.">here</a>'.format(fn=fn, ln=ln, loan=loan.id))
    return 0


if __name__ == "__main__":
    main(accept_loan_request)
